﻿using System;
using System.Collections.Generic;
using System.Linq;
using QuizLib;

namespace WpfQuiz.ViewModel
{
    public class QuestionViewModel
    {
        readonly Question _question;
        List<AnswerViewModel> _availableAnswers;

        public QuestionViewModel(Question question)
        {
            _question = question;
        }

        public string QuestionText
        {
            get { return _question.QuestionText; }
        }

        #region AvailableAnswers

        public List<AnswerViewModel> AvailableAnswers
        {
            get
            {
                if (_availableAnswers == null)
                {
                    this.CreateAnswers();
                }
                return _availableAnswers;
            }
        }

        void CreateAnswers()
        {
            _availableAnswers = new List<AnswerViewModel>();
            int index = 0;
            string questionID = Guid.NewGuid().ToString();
            foreach (string answer in _question.AvailableAnswers)
                _availableAnswers.Add(new AnswerViewModel(_question, index++, questionID));
        }

        #endregion // AvailableAnswers

        #region WasAnsweredCorrectly

        internal bool WasAnsweredCorrectly
        {
            get
            {
                var proposedAnswer =
                    from answer in this.AvailableAnswers
                    where answer.IsSelected
                    select answer.GetIndex();

                return _question.IsCorrectAnswer(proposedAnswer.ToArray());
            }
        }

        #endregion // WasAnsweredCorrectly
    }
}
