﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using BusinessObjects;
using System.Collections;
using System.Windows.Media.Imaging;
using System.Drawing;



namespace DataService
{

    public class CustomerBuilder
    {
        private  static char[] _delimiter = { '\t' };
        private enum Fields { ID, FirstName, LastName, CompanyName, EmailAddress, ImageFileName};

        public static Customer[] BuildCustomers(string rawFileName)
        {
            ArrayList customers = new ArrayList();
            using (StreamReader streamReader = new StreamReader(rawFileName, Encoding.Default))
            {
                

                while (streamReader.Peek() >= 0)
                {
                    string rawLine = streamReader.ReadLine();
                
                        string[] fields = rawLine.Split(_delimiter, StringSplitOptions.None);
                        Customer customer = new Customer();
                        customer.ID = fields[(int)Fields.ID];
                        customer.FirstName = fields[(int)Fields.FirstName];
                        customer.LastName = fields[(int)Fields.LastName];
                        customer.CompanyName = fields[(int)Fields.CompanyName];
                        customer.EmailAddress = fields[(int)Fields.EmailAddress];
                        SetCustomerImage(customer, fields[(int)Fields.ImageFileName]);
                        
                        customers.Add(customer);
                   
                    
                }

            }


            return (Customer[])customers.ToArray(typeof(Customer));
        }


        public static void SaveCustomers(Customer[] customers, string rawFileName)
        {
            string delimiter = new string(_delimiter);
            using (StreamWriter streamWriter = new StreamWriter(rawFileName))
            {
                StringBuilder customerLine = new StringBuilder();
                foreach (Customer customer in customers)
                {
                    customerLine.Append(customer.ID + delimiter);
                    customerLine.Append(customer.FirstName + delimiter);
                    customerLine.Append(customer.LastName + delimiter);
                    customerLine.Append(customer.CompanyName + delimiter);
                    customerLine.Append(customer.EmailAddress + delimiter);
                    FileInfo fileInfo = new FileInfo(rawFileName);
                    customerLine.Append(fileInfo.Directory + @"\" + customer.ID + ".jpg");
                    streamWriter.WriteLine(customerLine.ToString());
                    customerLine.Clear();
                }
            }
        }

        private static void PersistCustomerImage(Customer customer,DirectoryInfo directory)
        {

            string photolocation = directory + @"\" +  customer.ID + ".jpg";  //file name
            using (FileStream filestream = new FileStream(photolocation, FileMode.Create))
            {
                JpegBitmapEncoder encoder = new JpegBitmapEncoder();
                encoder.Frames.Add(BitmapFrame.Create(customer.Image));
                encoder.Save(filestream);
                encoder = null;
            }
        }

        private static void SetCustomerImage(Customer customer, string filePath)
        {            
            BitmapImage image = new BitmapImage();
            image.BeginInit();
            image.UriSource = new Uri(filePath);
            image.EndInit();
            customer.Image = image;
           
            
        }



    }
}
