﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Input;
using BusinessObjects;
using System.ComponentModel;
using System.Collections;
using ViewModels.Commands;

namespace ViewModels
{
    public class CustomerViewModel : INotifyPropertyChanged
    {

        

        public CustomerViewModel()
        {
          
        }


        #region Events
        /// <summary>
        /// Property changed events to notifiy the Views that 
        /// a property has changed.
        /// </summary>          
        public event PropertyChangedEventHandler PropertyChanged;
        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        #region Properties
        private IEnumerable<Customer> _customers;
        public IEnumerable<Customer> Customers
        {
            get
            {
                return this._customers;
            }

            set
            {
                this._customers = value;
                this.OnPropertyChanged("Customers");
                this.OnPropertyChanged("CustomerCount");
            }
        }

        private Customer _currentCustomer;
        public Customer CurrentCustomer
        {
            get
            {
                return this._currentCustomer;
            }

            set
            {
                this._currentCustomer = value;
                this.OnPropertyChanged("CurrentCustomer");
            }

        }

        public string CustomerCount
        {
            get
            {
                int count = 0;
                if (_customers != null)
                {
                    foreach (Customer Customer in _customers)
                    {
                        count++;
                    }
                }
                return count.ToString();
            }
        }

        ICommand _getCustomersCmd;
        public ICommand GetCustomersCmd
        {
            get
            {
                if (_getCustomersCmd == null)
                {
                    _getCustomersCmd = new GetCustomersCommand(this);
                }
                return _getCustomersCmd;
            }
        }

        ICommand _saveCustomersCmd;
        public ICommand SaveCustomersCmd
        {
            get
            {
                if (_saveCustomersCmd == null)
                {
                    _saveCustomersCmd = new SaveCustomersCommand(this);
                }
                return _saveCustomersCmd;
            }
        }

        #endregion
        #region Public Methods

        public void GetCustomers()
        {
            // Get customers from Model
            this.Customers = DataService.CustomerDataService.GetCustomers();
        }

        public void SaveCustomers()
        {
            if (_customers != null)
            {
                ArrayList customers = new ArrayList();
                foreach (Customer customer in _customers)
                {
                    customers.Add(customer);
                }
                DataService.CustomerDataService.SaveCustomers((Customer[])customers.ToArray(typeof(Customer)));
            }
        }


        #endregion
    }
}