﻿//using System.Windows;
//using QuizLib;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using BusinessObjects;
using System.ComponentModel;
using System.Collections;
using System.IO;
using System.Windows.Input;

namespace ViewModels
{
    public class CustomerViewModel : INotifyPropertyChanged
    {

        ICommand _getCustomersCmd;

        public CustomerViewModel()
        {
          
        }

       

        #region ShowResultsCmd

        public ICommand ShowResultsCmd
        {
            get
            {
                if (_getCustomersCmd == null)
                {
                    _getCustomersCmd = new ShowResultsCommand(this);
                }
                return _getCustomersCmd;
            }
        }



        private class ShowResultsCommand : ICommand
        {
            readonly CustomerViewModel _viewModel;

            public ShowResultsCommand(CustomerViewModel customerViewModel)
            {
                _viewModel = customerViewModel;
            }

            #region ICommand Members

            public bool CanExecute(object parameter)
            {
                return true;
            }

            public event EventHandler CanExecuteChanged;

            public void Execute(object parameter)
            {
                _viewModel.GetCustomers();
            }

            #endregion
        }

        #endregion // ShowResultsCmd

        //888ar New Stuff
        #region Events
        /// <summary>
        /// Property changed events to notifiy the Views that 
        /// a property has changed.
        /// </summary>          
        public event PropertyChangedEventHandler PropertyChanged;
        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        #region Properties
        private IEnumerable<Customer> _customers;
        public IEnumerable<Customer> Customers
        {
            get
            {
                return this._customers;
            }

            set
            {
                this._customers = value;
                this.OnPropertyChanged("Customers");
                this.OnPropertyChanged("CustomerCount");
            }
        }

        private Customer _currentCustomer;
        public Customer CurrentCustomer
        {
            get
            {
                return this._currentCustomer;
            }

            set
            {
                this._currentCustomer = value;
                this.OnPropertyChanged("CurrentCustomer");
            }

        }

        public string CustomerCount
        {
            get
            {
                int count = 0;
                if (_customers != null)
                {
                    foreach (Customer Customer in _customers)
                    {
                        count++;
                    }
                }
                return count.ToString();
            }
        }


        #endregion
        #region Public Methods

        public void GetCustomers()
        {
            // Get customers from Model
            this.Customers = DataService.CustomerDataService.GetCustomers();
        }

        public void SaveCustomers()
        {
            if (_customers != null)
            {
                ArrayList customers = new ArrayList();
                foreach (Customer customer in _customers)
                {
                    customers.Add(customer);
                }
                DataService.CustomerDataService.SaveCustomers((Customer[])customers.ToArray(typeof(Customer)));
            }
        }


        #endregion
    }
}